"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ethers_1 = require("ethers");
const const_1 = require("./const");
const contracts_1 = require("./contracts");
async function migrateIssuer(web3ProviderUrl, deployKey, registryAddress) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const provider = new ethers_1.ethers.providers.JsonRpcProvider(web3ProviderUrl);
    const wallet = new ethers_1.ethers.Wallet(privateKeyDeployment, provider);
    const issuerContract = await new contracts_1.factories.IssuerFactory(wallet).deploy();
    await issuerContract.deployed();
    const tx = await issuerContract.initialize(const_1.CertificateTopic.IREC, registryAddress, wallet.address);
    await tx.wait();
    const version = await issuerContract.version();
    console.log(`Issuer ${version} created at ${issuerContract.address}`);
    return issuerContract;
}
exports.migrateIssuer = migrateIssuer;
async function migrateRegistry(web3ProviderUrl, deployKey) {
    const privateKeyDeployment = deployKey.startsWith('0x') ? deployKey : `0x${deployKey}`;
    const provider = new ethers_1.ethers.providers.JsonRpcProvider(web3ProviderUrl);
    const wallet = new ethers_1.ethers.Wallet(privateKeyDeployment, provider);
    const registryContract = await new contracts_1.factories.RegistryFactory(wallet).deploy();
    await registryContract.deployed();
    const tx = await registryContract.initialize();
    await tx.wait();
    console.log(`Registry created at ${registryContract.address}`);
    return registryContract;
}
exports.migrateRegistry = migrateRegistry;
//# sourceMappingURL=migrate.js.map